==> eiffelstudio-18.11.10.2592.tar: F_code/C6/ut266.c <==
/*
 * Code for class UT_ERROR_HANDLER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ut266.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {UT_ERROR_HANDLER}.make_standard */
void F914_6080 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(182,F8_182,(RTCV(RTOSCF(1333,F154_1333,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(182,F8_182,(RTCV(RTOSCF(1333,F154_1333,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(181,F8_181,(RTCV(RTOSCF(1333,F154_1333,(Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_error */
void F914_6082 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = F914_6101(Current, arg1);
	F914_6085(Current, tr1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_info */
void F914_6084 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = F914_6101(Current, arg1);
	F914_6087(Current, tr1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_error_message */
void F914_6085 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	F691_3247(RTCW(tr1), arg1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_info_message */
void F914_6087 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	F691_3247(RTCW(tr1), arg1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.error_file */
EIF_REFERENCE F914_6088 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {UT_ERROR_HANDLER}.warning_file */
EIF_REFERENCE F914_6089 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {UT_ERROR_HANDLER}.info_file */
EIF_REFERENCE F914_6090 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {UT_ERROR_HANDLER}.message */
EIF_REFERENCE F914_6101 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	
	
	tr1 = F925_6444(RTCW(arg1));
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit266 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/ut266.c <==
/*
 * Code for class UT_ERROR_HANDLER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ut266.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {UT_ERROR_HANDLER}.make_standard */
void F918_6114 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOUCR(35,F8_182, (RTCV(RTOUCR(3,F154_1336, (Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	tr1 = RTOUCR(35,F8_182, (RTCV(RTOUCR(3,F154_1336, (Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = RTOUCR(2,F8_181, (RTCV(RTOUCR(3,F154_1336, (Current)))));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_error */
void F918_6116 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = F918_6135(Current, arg1);
	F918_6119(Current, tr1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_info */
void F918_6118 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = F918_6135(Current, arg1);
	F918_6121(Current, tr1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_error_message */
void F918_6119 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	F691_3257(RTCW(tr1), arg1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.report_info_message */
void F918_6121 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	F691_3257(RTCW(tr1), arg1);
	RTLE;
}

/* {UT_ERROR_HANDLER}.message */
EIF_REFERENCE F918_6135 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	
	
	tr1 = F930_6478(RTCW(arg1));
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit266 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
